#!/usr/bin/env python
#-*- coding:utf-8 -*-
#==============================================================================
#  Copyright (C) 2010-2012 Schaefer & Tobies SuC GmbH.
#  Author: Markus Grimm <mgr@schaefer-tobies.de>
#
#  This file is part of Pyontapi.
#
#  Pyontapi is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyontapi is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Pyontapi.  If not, see <http://www.gnu.org/licenses/>.
#
#==============================================================================

""" pyontapi Exception classes """

from schtob.pyontapi.na_errno import NA_ERRNO


class PyontapiError(Exception):
    """ Base class for Pyontapi Exceptions """
    pass


class APIFailure(PyontapiError):

    """ Exception class for unsuccessful ONTAPI calls. """

    def __init__(self, errno, reason):
        PyontapiError.__init__(self)
        self.errno = errno
        self.reason = reason
        self.errname = ""
        if self.errno in NA_ERRNO:
            self.errname = NA_ERRNO[self.errno]

    def get_error(self):
        """ Returns an error message. """
        if self.errno > -1:
            return '%(reason)s (Err Nr. %(errno)s - %(errname)s)' % {
                'errname': self.errname,
                'reason': self.reason,
                'errno': self.errno,
            }
        return self.reason

    def get_errno(self):
        """ Returns the error number. """
        return self.errno

    def __str__(self):
        return self.get_error()


class UnknownOntapiVersionError(APIFailure):
    """ Cannot get ONTAPI version. """
    pass


class OntapiVersionError(APIFailure):
    """ Cannot get informations to API commands and type elements. """
    pass


class APIGenerationError(APIFailure):
    """ API generation was not successful. """
    pass
